Overview
========
Python client to the linx multipath-tools deamon
Usage
-----

```python
>>> from infi.multipathtools import MultipathClient
>>> client = MultipathClient()
```

Checking out the code
=====================

Run the following:

    easy_install -U infi.projector
    projector devenv build

Python 3
========

Python 3 support is experimental at this stage.
